@@ -1,6 +1,7 @@
 from django import template
 
 from .rawjstemplate import rawjstemplate
+from .handlebarsjs import handlebarsjs
 from .mustachejs import mustachejs
 from .icanhazjs import icanhazjs
 from .dustjs import dustjs
@@ -9,6 +10,7 @@ register = template.Library()
 
 
 register.tag(rawjstemplate)
+register.tag(handlebarsjs)
 register.tag(mustachejs)
 register.tag(icanhazjs)
 register.tag(dustjs)
